@@ -3,7 +3,7 @@ BEGIN {
   $App::EvalServer::AUTHORITY = 'cpan:HINRIK';
 }
 BEGIN {
-  $App::EvalServer::VERSION = '0.04';
+  $App::EvalServer::VERSION = '0.05';
 }
 
 use strict;
@@ -66,7 +66,10 @@ sub run {
 
     if ($self->{daemonize}) {
         require Proc::Daemon;
-        eval { Proc::Daemon::Init->() };
+        eval {
+            Proc::Daemon::Init->();
+            $poe_kernel->has_forked();
+        };
         chomp $@; 
         die "Can't daemonize: $@\n" if $@;
     }
